@@ -5,6 +5,7 @@ class SparkPostException(Exception):
 class SparkPostAPIException(SparkPostException):
     "Handle 4xx and 5xx errors from the SparkPost API"
     def __init__(self, response, *args, **kwargs):
+        # noinspection PyBroadException
         try:
             errors = response.json()['errors']
             error_template = "{message} Code: {code} Description: {desc} \n"
@@ -12,7 +13,8 @@ class SparkPostAPIException(SparkPostException):
                                             code=e.get('code', 'none'),
                                             desc=e.get('description', 'none'))
                       for e in errors]
-        except:
+        # TODO: select exception to catch here
+        except:  # noqa: E722
             errors = [response.text or ""]
         self.status = response.status_code
         self.response = response
