@@ -17,8 +17,8 @@ from sparkpost.exceptions import SparkPostAPIException, SparkPostException
 def test_translate_keys_with_list():
     t = Transmissions('uri', 'key')
     results = t._translate_keys(recipient_list='test')
-    assert results['content']['use_draft_template'] is False
-    assert isinstance(results['content']['headers'], dict)
+    assert 'use_draft_template' not in results['content']
+    assert 'headers' not in results['content']
     assert results['recipients'] == {'list_id': 'test'}
 
 
@@ -66,6 +66,20 @@ def test_translate_keys_for_from_email():
     }
 
 
+@responses.activate
+def test_campaign_id():
+    responses.add(
+        responses.POST,
+        'https://api.sparkpost.com/api/v1/transmissions',
+        status=200,
+        content_type='application/json',
+        body='{"results": "yay"}'
+    )
+    sp = SparkPost('fake-key')
+    results = sp.transmission.send(campaign="test")
+    assert results == 'yay'
+
+
 def test_format_header_to():
     t = Transmissions('uri', 'key')
     formatted = t._format_header_to(recipient={
